#ifndef NT2_INCLUDE_FUNCTIONS_POLYADD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYADD_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyadd.hpp>

#endif
